package summarize

var stopWords = map[string]struct{}{
	"a":            empty,
	"about":        empty,
	"above":        empty,
	"across":       empty,
	"after":        empty,
	"afterwards":   empty,
	"again":        empty,
	"against":      empty,
	"all":          empty,
	"almost":       empty,
	"alone":        empty,
	"along":        empty,
	"already":      empty,
	"also":         empty,
	"although":     empty,
	"always":       empty,
	"am":           empty,
	"among":        empty,
	"amongst":      empty,
	"amount":       empty,
	"an":           empty,
	"and":          empty,
	"another":      empty,
	"any":          empty,
	"anyhow":       empty,
	"anyone":       empty,
	"anything":     empty,
	"anyway":       empty,
	"anywhere":     empty,
	"are":          empty,
	"around":       empty,
	"as":           empty,
	"at":           empty,
	"back":         empty,
	"be":           empty,
	"became":       empty,
	"because":      empty,
	"become":       empty,
	"becomes":      empty,
	"becoming":     empty,
	"been":         empty,
	"before":       empty,
	"beforehand":   empty,
	"behind":       empty,
	"being":        empty,
	"below":        empty,
	"beside":       empty,
	"besides":      empty,
	"between":      empty,
	"beyond":       empty,
	"bill":         empty,
	"both":         empty,
	"bottom":       empty,
	"but":          empty,
	"by":           empty,
	"call":         empty,
	"can":          empty,
	"cannot":       empty,
	"cant":         empty,
	"co":           empty,
	"con":          empty,
	"could":        empty,
	"couldnt":      empty,
	"cry":          empty,
	"de":           empty,
	"describe":     empty,
	"detail":       empty,
	"do":           empty,
	"done":         empty,
	"down":         empty,
	"due":          empty,
	"during":       empty,
	"each":         empty,
	"eg":           empty,
	"eight":        empty,
	"either":       empty,
	"eleven":       empty,
	"else":         empty,
	"elsewhere":    empty,
	"empty":        empty,
	"enough":       empty,
	"etc":          empty,
	"even":         empty,
	"ever":         empty,
	"every":        empty,
	"everyone":     empty,
	"everything":   empty,
	"everywhere":   empty,
	"except":       empty,
	"few":          empty,
	"fifteen":      empty,
	"fify":         empty,
	"fill":         empty,
	"find":         empty,
	"fire":         empty,
	"first":        empty,
	"five":         empty,
	"for":          empty,
	"former":       empty,
	"formerly":     empty,
	"forty":        empty,
	"found":        empty,
	"four":         empty,
	"from":         empty,
	"front":        empty,
	"full":         empty,
	"further":      empty,
	"get":          empty,
	"give":         empty,
	"go":           empty,
	"had":          empty,
	"has":          empty,
	"hasnt":        empty,
	"have":         empty,
	"he":           empty,
	"hence":        empty,
	"her":          empty,
	"here":         empty,
	"hereafter":    empty,
	"hereby":       empty,
	"herein":       empty,
	"hereupon":     empty,
	"hers":         empty,
	"herself":      empty,
	"him":          empty,
	"himself":      empty,
	"his":          empty,
	"how":          empty,
	"however":      empty,
	"hundred":      empty,
	"ie":           empty,
	"if":           empty,
	"in":           empty,
	"inc":          empty,
	"indeed":       empty,
	"interest":     empty,
	"into":         empty,
	"is":           empty,
	"it":           empty,
	"its":          empty,
	"itself":       empty,
	"keep":         empty,
	"last":         empty,
	"latter":       empty,
	"latterly":     empty,
	"least":        empty,
	"less":         empty,
	"ltd":          empty,
	"made":         empty,
	"many":         empty,
	"may":          empty,
	"me":           empty,
	"meanwhile":    empty,
	"might":        empty,
	"mill":         empty,
	"mine":         empty,
	"more":         empty,
	"moreover":     empty,
	"most":         empty,
	"mostly":       empty,
	"move":         empty,
	"much":         empty,
	"must":         empty,
	"my":           empty,
	"myself":       empty,
	"name":         empty,
	"namely":       empty,
	"neither":      empty,
	"never":        empty,
	"nevertheless": empty,
	"next":         empty,
	"nine":         empty,
	"no":           empty,
	"nobody":       empty,
	"none":         empty,
	"noone":        empty,
	"nor":          empty,
	"not":          empty,
	"nothing":      empty,
	"now":          empty,
	"nowhere":      empty,
	"of":           empty,
	"off":          empty,
	"often":        empty,
	"on":           empty,
	"once":         empty,
	"one":          empty,
	"only":         empty,
	"onto":         empty,
	"or":           empty,
	"other":        empty,
	"others":       empty,
	"otherwise":    empty,
	"our":          empty,
	"ours":         empty,
	"ourselves":    empty,
	"out":          empty,
	"over":         empty,
	"own":          empty,
	"part":         empty,
	"per":          empty,
	"perhaps":      empty,
	"please":       empty,
	"put":          empty,
	"rather":       empty,
	"re":           empty,
	"same":         empty,
	"see":          empty,
	"seem":         empty,
	"seemed":       empty,
	"seeming":      empty,
	"seems":        empty,
	"serious":      empty,
	"several":      empty,
	"she":          empty,
	"should":       empty,
	"show":         empty,
	"side":         empty,
	"since":        empty,
	"sincere":      empty,
	"six":          empty,
	"sixty":        empty,
	"so":           empty,
	"some":         empty,
	"somehow":      empty,
	"someone":      empty,
	"something":    empty,
	"sometime":     empty,
	"sometimes":    empty,
	"somewhere":    empty,
	"still":        empty,
	"such":         empty,
	"system":       empty,
	"take":         empty,
	"ten":          empty,
	"than":         empty,
	"that":         empty,
	"the":          empty,
	"their":        empty,
	"them":         empty,
	"themselves":   empty,
	"then":         empty,
	"thence":       empty,
	"there":        empty,
	"thereafter":   empty,
	"thereby":      empty,
	"therefore":    empty,
	"therein":      empty,
	"thereupon":    empty,
	"these":        empty,
	"they":         empty,
	"thickv":       empty,
	"thin":         empty,
	"third":        empty,
	"this":         empty,
	"those":        empty,
	"though":       empty,
	"three":        empty,
	"through":      empty,
	"throughout":   empty,
	"thru":         empty,
	"thus":         empty,
	"to":           empty,
	"together":     empty,
	"too":          empty,
	"top":          empty,
	"toward":       empty,
	"towards":      empty,
	"twelve":       empty,
	"twenty":       empty,
	"two":          empty,
	"un":           empty,
	"under":        empty,
	"until":        empty,
	"up":           empty,
	"upon":         empty,
	"us":           empty,
	"very":         empty,
	"via":          empty,
	"was":          empty,
	"we":           empty,
	"well":         empty,
	"were":         empty,
	"what":         empty,
	"whatever":     empty,
	"when":         empty,
	"whence":       empty,
	"whenever":     empty,
	"where":        empty,
	"whereafter":   empty,
	"whereas":      empty,
	"whereby":      empty,
	"wherein":      empty,
	"whereupon":    empty,
	"wherever":     empty,
	"whether":      empty,
	"which":        empty,
	"while":        empty,
	"whither":      empty,
	"who":          empty,
	"whoever":      empty,
	"whole":        empty,
	"whom":         empty,
	"whose":        empty,
	"why":          empty,
	"will":         empty,
	"with":         empty,
	"within":       empty,
	"without":      empty,
	"would":        empty,
	"yet":          empty,
	"you":          empty,
	"your":         empty,
	"yours":        empty,
	"yourself":     empty,
	"yourselves":   empty,
}
