package summarize

var empty struct{}

var easyWords = map[string]struct{}{
	"a": empty,
	"able": empty,
	"aboard": empty,
	"about": empty,
	"above": empty,
	"absent": empty,
	"accept": empty,
	"accident": empty,
	"account": empty,
	"ache": empty,
	"aching": empty,
	"acorn": empty,
	"acre": empty,
	"across": empty,
	"act": empty,
	"acts": empty,
	"add": empty,
	"address": empty,
	"admire": empty,
	"adventure": empty,
	"afar": empty,
	"afraid": empty,
	"after": empty,
	"afternoon": empty,
	"afterward": empty,
	"afterwards": empty,
	"again": empty,
	"against": empty,
	"age": empty,
	"aged": empty,
	"ago": empty,
	"agree": empty,
	"ah": empty,
	"ahead": empty,
	"aid": empty,
	"aim": empty,
	"air": empty,
	"airfield": empty,
	"airplane": empty,
	"airport": empty,
	"airship": empty,
	"airy": empty,
	"alarm": empty,
	"alike": empty,
	"alive": empty,
	"all": empty,
	"alley": empty,
	"alligator": empty,
	"allow": empty,
	"almost": empty,
	"alone": empty,
	"along": empty,
	"aloud": empty,
	"already": empty,
	"also": empty,
	"always": empty,
	"am": empty,
	"America": empty,
	"American": empty,
	"among": empty,
	"amount": empty,
	"an": empty,
	"and": empty,
	"angel": empty,
	"anger": empty,
	"angry": empty,
	"animal": empty,
	"another": empty,
	"answer": empty,
	"ant": empty,
	"any": empty,
	"anybody": empty,
	"anyhow": empty,
	"anyone": empty,
	"anything": empty,
	"anyway": empty,
	"anywhere": empty,
	"apart": empty,
	"apartment": empty,
	"ape": empty,
	"apiece": empty,
	"appear": empty,
	"apple": empty,
	"April": empty,
	"apron": empty,
	"are": empty,
	"aren't": empty,
	"arise": empty,
	"arithmetic": empty,
	"arm": empty,
	"armful": empty,
	"army": empty,
	"arose": empty,
	"around": empty,
	"arrange": empty,
	"arrive": empty,
	"arrived": empty,
	"arrow": empty,
	"art": empty,
	"artist": empty,
	"as": empty,
	"ash": empty,
	"ashes": empty,
	"aside": empty,
	"ask": empty,
	"asleep": empty,
	"at": empty,
	"ate": empty,
	"attack": empty,
	"attend": empty,
	"attention": empty,
	"August": empty,
	"aunt": empty,
	"author": empty,
	"auto": empty,
	"automobile": empty,
	"autumn": empty,
	"avenue": empty,
	"awake": empty,
	"awaken": empty,
	"away": empty,
	"awful": empty,
	"awfully": empty,
	"awhile": empty,
	"ax": empty,
	"axe": empty,
	"baa": empty,
	"babe": empty,
	"babies": empty,
	"back": empty,
	"background": empty,
	"backward": empty,
	"backwards": empty,
	"bacon": empty,
	"bad": empty,
	"badge": empty,
	"badly": empty,
	"bag": empty,
	"bake": empty,
	"baker": empty,
	"bakery": empty,
	"baking": empty,
	"ball": empty,
	"balloon": empty,
	"banana": empty,
	"band": empty,
	"bandage": empty,
	"bang": empty,
	"banjo": empty,
	"bank": empty,
	"banker": empty,
	"bar": empty,
	"barber": empty,
	"bare": empty,
	"barefoot": empty,
	"barely": empty,
	"bark": empty,
	"barn": empty,
	"barrel": empty,
	"base": empty,
	"baseball": empty,
	"basement": empty,
	"basket": empty,
	"bat": empty,
	"batch": empty,
	"bath": empty,
	"bathe": empty,
	"bathing": empty,
	"bathroom": empty,
	"bathtub": empty,
	"battle": empty,
	"battleship": empty,
	"bay": empty,
	"be": empty,
	"beach": empty,
	"bead": empty,
	"beam": empty,
	"bean": empty,
	"bear": empty,
	"beard": empty,
	"beast": empty,
	"beat": empty,
	"beating": empty,
	"beautiful": empty,
	"beautify": empty,
	"beauty": empty,
	"became": empty,
	"because": empty,
	"become": empty,
	"becoming": empty,
	"bed": empty,
	"bedbug": empty,
	"bedroom": empty,
	"bedspread": empty,
	"bedtime": empty,
	"bee": empty,
	"beech": empty,
	"beef": empty,
	"beefsteak": empty,
	"beehive": empty,
	"been": empty,
	"beer": empty,
	"beet": empty,
	"before": empty,
	"beg": empty,
	"began": empty,
	"beggar": empty,
	"begged": empty,
	"begin": empty,
	"beginning": empty,
	"begun": empty,
	"behave": empty,
	"behind": empty,
	"being": empty,
	"believe": empty,
	"bell": empty,
	"belong": empty,
	"below": empty,
	"belt": empty,
	"bench": empty,
	"bend": empty,
	"beneath": empty,
	"bent": empty,
	"berries": empty,
	"berry": empty,
	"beside": empty,
	"besides": empty,
	"best": empty,
	"bet": empty,
	"better": empty,
	"between": empty,
	"bib": empty,
	"bible": empty,
	"bicycle": empty,
	"bid": empty,
	"big": empty,
	"bigger": empty,
	"bill": empty,
	"billboard": empty,
	"bin": empty,
	"bind": empty,
	"bird": empty,
	"birth": empty,
	"birthday": empty,
	"biscuit": empty,
	"bit": empty,
	"bite": empty,
	"biting": empty,
	"bitter": empty,
	"black": empty,
	"blackberry": empty,
	"blackbird": empty,
	"blackboard": empty,
	"blackness": empty,
	"blacksmith": empty,
	"blame": empty,
	"blank": empty,
	"blanket": empty,
	"blast": empty,
	"blaze": empty,
	"bleed": empty,
	"bless": empty,
	"blessing": empty,
	"blew": empty,
	"blind": empty,
	"blindfold": empty,
	"blinds": empty,
	"block": empty,
	"blood": empty,
	"bloom": empty,
	"blossom": empty,
	"blot": empty,
	"blow": empty,
	"blue": empty,
	"blueberry": empty,
	"bluebird": empty,
	"blush": empty,
	"board": empty,
	"boast": empty,
	"boat": empty,
	"bob": empty,
	"bobwhite": empty,
	"bodies": empty,
	"body": empty,
	"boil": empty,
	"boiler": empty,
	"bold": empty,
	"bone": empty,
	"bonnet": empty,
	"boo": empty,
	"book": empty,
	"bookcase": empty,
	"bookkeeper": empty,
	"boom": empty,
	"boot": empty,
	"born": empty,
	"borrow": empty,
	"boss": empty,
	"both": empty,
	"bother": empty,
	"bottle": empty,
	"bottom": empty,
	"bought": empty,
	"bounce": empty,
	"bow": empty,
	"bowl": empty,
	"bow-wow": empty,
	"box": empty,
	"boxcar": empty,
	"boxer": empty,
	"boxes": empty,
	"boy": empty,
	"boyhood": empty,
	"bracelet": empty,
	"brain": empty,
	"brake": empty,
	"bran": empty,
	"branch": empty,
	"brass": empty,
	"brave": empty,
	"bread": empty,
	"break": empty,
	"breakfast": empty,
	"breast": empty,
	"breath": empty,
	"breathe": empty,
	"breeze": empty,
	"brick": empty,
	"bride": empty,
	"bridge": empty,
	"bright": empty,
	"brightness": empty,
	"bring": empty,
	"broad": empty,
	"broadcast": empty,
	"broke": empty,
	"broken": empty,
	"brook": empty,
	"broom": empty,
	"brother": empty,
	"brought": empty,
	"brown": empty,
	"brush": empty,
	"bubble": empty,
	"bucket": empty,
	"buckle": empty,
	"bud": empty,
	"buffalo": empty,
	"bug": empty,
	"buggy": empty,
	"build": empty,
	"building": empty,
	"built": empty,
	"bulb": empty,
	"bull": empty,
	"bullet": empty,
	"bum": empty,
	"bumblebee": empty,
	"bump": empty,
	"bun": empty,
	"bunch": empty,
	"bundle": empty,
	"bunny": empty,
	"burn": empty,
	"burst": empty,
	"bury": empty,
	"bus": empty,
	"bush": empty,
	"bushel": empty,
	"business": empty,
	"busy": empty,
	"but": empty,
	"butcher": empty,
	"butt": empty,
	"butter": empty,
	"buttercup": empty,
	"butterfly": empty,
	"buttermilk": empty,
	"butterscotch": empty,
	"button": empty,
	"buttonhole": empty,
	"buy": empty,
	"buzz": empty,
	"by": empty,
	"bye": empty,
	"cab": empty,
	"cabbage": empty,
	"cabin": empty,
	"cabinet": empty,
	"cackle": empty,
	"cage": empty,
	"cake": empty,
	"calendar": empty,
	"calf": empty,
	"call": empty,
	"caller": empty,
	"calling": empty,
	"came": empty,
	"camel": empty,
	"camp": empty,
	"campfire": empty,
	"can": empty,
	"canal": empty,
	"canary": empty,
	"candle": empty,
	"candlestick": empty,
	"candy": empty,
	"cane": empty,
	"cannon": empty,
	"cannot": empty,
	"canoe": empty,
	"can't": empty,
	"canyon": empty,
	"cap": empty,
	"cape": empty,
	"capital": empty,
	"captain": empty,
	"car": empty,
	"card": empty,
	"cardboard": empty,
	"care": empty,
	"careful": empty,
	"careless": empty,
	"carelessness": empty,
	"carload": empty,
	"carpenter": empty,
	"carpet": empty,
	"carriage": empty,
	"carrot": empty,
	"carry": empty,
	"cart": empty,
	"carve": empty,
	"case": empty,
	"cash": empty,
	"cashier": empty,
	"castle": empty,
	"cat": empty,
	"catbird": empty,
	"catch": empty,
	"catcher": empty,
	"caterpillar": empty,
	"catfish": empty,
	"catsup": empty,
	"cattle": empty,
	"caught": empty,
	"cause": empty,
	"cave": empty,
	"ceiling": empty,
	"cell": empty,
	"cellar": empty,
	"cent": empty,
	"center": empty,
	"cereal": empty,
	"certain": empty,
	"certainly": empty,
	"chain": empty,
	"chair": empty,
	"chalk": empty,
	"champion": empty,
	"chance": empty,
	"change": empty,
	"chap": empty,
	"charge": empty,
	"charm": empty,
	"chart": empty,
	"chase": empty,
	"chatter": empty,
	"cheap": empty,
	"cheat": empty,
	"check": empty,
	"checkers": empty,
	"cheek": empty,
	"cheer": empty,
	"cheese": empty,
	"cherry": empty,
	"chest": empty,
	"chew": empty,
	"chick": empty,
	"chicken": empty,
	"chief": empty,
	"child": empty,
	"childhood": empty,
	"children": empty,
	"chill": empty,
	"chilly": empty,
	"chimney": empty,
	"chin": empty,
	"china": empty,
	"chip": empty,
	"chipmunk": empty,
	"chocolate": empty,
	"choice": empty,
	"choose": empty,
	"chop": empty,
	"chorus": empty,
	"chose": empty,
	"chosen": empty,
	"christen": empty,
	"Christmas": empty,
	"church": empty,
	"churn": empty,
	"cigarette": empty,
	"circle": empty,
	"circus": empty,
	"citizen": empty,
	"city": empty,
	"clang": empty,
	"clap": empty,
	"class": empty,
	"classmate": empty,
	"classroom": empty,
	"claw": empty,
	"clay": empty,
	"clean": empty,
	"cleaner": empty,
	"clear": empty,
	"clerk": empty,
	"clever": empty,
	"click": empty,
	"cliff": empty,
	"climb": empty,
	"clip": empty,
	"cloak": empty,
	"clock": empty,
	"close": empty,
	"closet": empty,
	"cloth": empty,
	"clothes": empty,
	"clothing": empty,
	"cloud": empty,
	"cloudy": empty,
	"clover": empty,
	"clown": empty,
	"club": empty,
	"cluck": empty,
	"clump": empty,
	"coach": empty,
	"coal": empty,
	"coast": empty,
	"coat": empty,
	"cob": empty,
	"cobbler": empty,
	"cocoa": empty,
	"coconut": empty,
	"cocoon": empty,
	"cod": empty,
	"codfish": empty,
	"coffee": empty,
	"coffeepot": empty,
	"coin": empty,
	"cold": empty,
	"collar": empty,
	"college": empty,
	"color": empty,
	"colored": empty,
	"colt": empty,
	"column": empty,
	"comb": empty,
	"come": empty,
	"comfort": empty,
	"comic": empty,
	"coming": empty,
	"company": empty,
	"compare": empty,
	"conductor": empty,
	"cone": empty,
	"connect": empty,
	"coo": empty,
	"cook": empty,
	"cooked": empty,
	"cooking": empty,
	"cookie": empty,
	"cookies": empty,
	"cool": empty,
	"cooler": empty,
	"coop": empty,
	"copper": empty,
	"copy": empty,
	"cord": empty,
	"cork": empty,
	"corn": empty,
	"corner": empty,
	"correct": empty,
	"cost": empty,
	"cot": empty,
	"cottage": empty,
	"cotton": empty,
	"couch": empty,
	"cough": empty,
	"could": empty,
	"couldn't": empty,
	"count": empty,
	"counter": empty,
	"country": empty,
	"county": empty,
	"course": empty,
	"court": empty,
	"cousin": empty,
	"cover": empty,
	"cow": empty,
	"coward": empty,
	"cowardly": empty,
	"cowboy": empty,
	"cozy": empty,
	"crab": empty,
	"crack": empty,
	"cracker": empty,
	"cradle": empty,
	"cramps": empty,
	"cranberry": empty,
	"crank": empty,
	"cranky": empty,
	"crash": empty,
	"crawl": empty,
	"crazy": empty,
	"cream": empty,
	"creamy": empty,
	"creek": empty,
	"creep": empty,
	"crept": empty,
	"cried": empty,
	"croak": empty,
	"crook": empty,
	"crooked": empty,
	"crop": empty,
	"cross": empty,
	"crossing": empty,
	"cross-eyed": empty,
	"crow": empty,
	"crowd": empty,
	"crowded": empty,
	"crown": empty,
	"cruel": empty,
	"crumb": empty,
	"crumble": empty,
	"crush": empty,
	"crust": empty,
	"cry": empty,
	"cries": empty,
	"cub": empty,
	"cuff": empty,
	"cup": empty,
	"cupboard": empty,
	"cupful": empty,
	"cure": empty,
	"curl": empty,
	"curly": empty,
	"curtain": empty,
	"curve": empty,
	"cushion": empty,
	"custard": empty,
	"customer": empty,
	"cut": empty,
	"cute": empty,
	"cutting": empty,
	"dab": empty,
	"dad": empty,
	"daddy": empty,
	"daily": empty,
	"dairy": empty,
	"daisy": empty,
	"dam": empty,
	"damage": empty,
	"dame": empty,
	"damp": empty,
	"dance": empty,
	"dancer": empty,
	"dancing": empty,
	"dandy": empty,
	"danger": empty,
	"dangerous": empty,
	"dare": empty,
	"dark": empty,
	"darkness": empty,
	"darling": empty,
	"darn": empty,
	"dart": empty,
	"dash": empty,
	"date": empty,
	"daughter": empty,
	"dawn": empty,
	"day": empty,
	"daybreak": empty,
	"daytime": empty,
	"dead": empty,
	"deaf": empty,
	"deal": empty,
	"dear": empty,
	"death": empty,
	"December": empty,
	"decide": empty,
	"deck": empty,
	"deed": empty,
	"deep": empty,
	"deer": empty,
	"defeat": empty,
	"defend": empty,
	"defense": empty,
	"delight": empty,
	"den": empty,
	"dentist": empty,
	"depend": empty,
	"deposit": empty,
	"describe": empty,
	"desert": empty,
	"deserve": empty,
	"desire": empty,
	"desk": empty,
	"destroy": empty,
	"devil": empty,
	"dew": empty,
	"diamond": empty,
	"did": empty,
	"didn't": empty,
	"die": empty,
	"died": empty,
	"dies": empty,
	"difference": empty,
	"different": empty,
	"dig": empty,
	"dim": empty,
	"dime": empty,
	"dine": empty,
	"ding-dong": empty,
	"dinner": empty,
	"dip": empty,
	"direct": empty,
	"direction": empty,
	"dirt": empty,
	"dirty": empty,
	"discover": empty,
	"dish": empty,
	"dislike": empty,
	"dismiss": empty,
	"ditch": empty,
	"dive": empty,
	"diver": empty,
	"divide": empty,
	"do": empty,
	"dock": empty,
	"doctor": empty,
	"does": empty,
	"doesn't": empty,
	"dog": empty,
	"doll": empty,
	"dollar": empty,
	"dolly": empty,
	"done": empty,
	"donkey": empty,
	"don't": empty,
	"door": empty,
	"doorbell": empty,
	"doorknob": empty,
	"doorstep": empty,
	"dope": empty,
	"dot": empty,
	"double": empty,
	"dough": empty,
	"dove": empty,
	"down": empty,
	"downstairs": empty,
	"downtown": empty,
	"dozen": empty,
	"drag": empty,
	"drain": empty,
	"drank": empty,
	"draw": empty,
	"drawer": empty,
	"drawing": empty,
	"dream": empty,
	"dress": empty,
	"dresser": empty,
	"dressmaker": empty,
	"drew": empty,
	"dried": empty,
	"drift": empty,
	"drill": empty,
	"drink": empty,
	"drip": empty,
	"drive": empty,
	"driven": empty,
	"driver": empty,
	"drop": empty,
	"drove": empty,
	"drown": empty,
	"drowsy": empty,
	"drub": empty,
	"drum": empty,
	"drunk": empty,
	"dry": empty,
	"duck": empty,
	"due": empty,
	"dug": empty,
	"dull": empty,
	"dumb": empty,
	"dump": empty,
	"during": empty,
	"dust": empty,
	"dusty": empty,
	"duty": empty,
	"dwarf": empty,
	"dwell": empty,
	"dwelt": empty,
	"dying": empty,
	"each": empty,
	"eager": empty,
	"eagle": empty,
	"ear": empty,
	"early": empty,
	"earn": empty,
	"earth": empty,
	"east": empty,
	"eastern": empty,
	"easy": empty,
	"eat": empty,
	"eaten": empty,
	"edge": empty,
	"egg": empty,
	"eh": empty,
	"eight": empty,
	"eighteen": empty,
	"eighth": empty,
	"eighty": empty,
	"either": empty,
	"elbow": empty,
	"elder": empty,
	"eldest": empty,
	"electric": empty,
	"electricity": empty,
	"elephant": empty,
	"eleven": empty,
	"elf": empty,
	"elm": empty,
	"else": empty,
	"elsewhere": empty,
	"empty": empty,
	"end": empty,
	"ending": empty,
	"enemy": empty,
	"engine": empty,
	"engineer": empty,
	"English": empty,
	"enjoy": empty,
	"enough": empty,
	"enter": empty,
	"envelope": empty,
	"equal": empty,
	"erase": empty,
	"eraser": empty,
	"errand": empty,
	"escape": empty,
	"eve": empty,
	"even": empty,
	"evening": empty,
	"ever": empty,
	"every": empty,
	"everybody": empty,
	"everyday": empty,
	"everyone": empty,
	"everything": empty,
	"everywhere": empty,
	"evil": empty,
	"exact": empty,
	"except": empty,
	"exchange": empty,
	"excited": empty,
	"exciting": empty,
	"excuse": empty,
	"exit": empty,
	"expect": empty,
	"explain": empty,
	"extra": empty,
	"eye": empty,
	"eyebrow": empty,
	"fable": empty,
	"face": empty,
	"facing": empty,
	"fact": empty,
	"factory": empty,
	"fail": empty,
	"faint": empty,
	"fair": empty,
	"fairy": empty,
	"faith": empty,
	"fake": empty,
	"fall": empty,
	"false": empty,
	"family": empty,
	"fan": empty,
	"fancy": empty,
	"far": empty,
	"faraway": empty,
	"fare": empty,
	"farmer": empty,
	"farm": empty,
	"farming": empty,
	"far-off": empty,
	"farther": empty,
	"fashion": empty,
	"fast": empty,
	"fasten": empty,
	"fat": empty,
	"father": empty,
	"fault": empty,
	"favor": empty,
	"favorite": empty,
	"fear": empty,
	"feast": empty,
	"feather": empty,
	"February": empty,
	"fed": empty,
	"feed": empty,
	"feel": empty,
	"feet": empty,
	"fell": empty,
	"fellow": empty,
	"felt": empty,
	"fence": empty,
	"fever": empty,
	"few": empty,
	"fib": empty,
	"fiddle": empty,
	"field": empty,
	"fife": empty,
	"fifteen": empty,
	"fifth": empty,
	"fifty": empty,
	"fig": empty,
	"fight": empty,
	"figure": empty,
	"file": empty,
	"fill": empty,
	"film": empty,
	"finally": empty,
	"find": empty,
	"fine": empty,
	"finger": empty,
	"finish": empty,
	"fire": empty,
	"firearm": empty,
	"firecracker": empty,
	"fireplace": empty,
	"fireworks": empty,
	"firing": empty,
	"first": empty,
	"fish": empty,
	"fisherman": empty,
	"fist": empty,
	"fit": empty,
	"fits": empty,
	"five": empty,
	"fix": empty,
	"flag": empty,
	"flake": empty,
	"flame": empty,
	"flap": empty,
	"flash": empty,
	"flashlight": empty,
	"flat": empty,
	"flea": empty,
	"flesh": empty,
	"flew": empty,
	"flies": empty,
	"flight": empty,
	"flip": empty,
	"flip-flop": empty,
	"float": empty,
	"flock": empty,
	"flood": empty,
	"floor": empty,
	"flop": empty,
	"flour": empty,
	"flow": empty,
	"flower": empty,
	"flowery": empty,
	"flutter": empty,
	"fly": empty,
	"foam": empty,
	"fog": empty,
	"foggy": empty,
	"fold": empty,
	"folks": empty,
	"follow": empty,
	"following": empty,
	"fond": empty,
	"food": empty,
	"fool": empty,
	"foolish": empty,
	"foot": empty,
	"football": empty,
	"footprint": empty,
	"for": empty,
	"forehead": empty,
	"forest": empty,
	"forget": empty,
	"forgive": empty,
	"forgot": empty,
	"forgotten": empty,
	"fork": empty,
	"form": empty,
	"fort": empty,
	"forth": empty,
	"fortune": empty,
	"forty": empty,
	"forward": empty,
	"fought": empty,
	"found": empty,
	"fountain": empty,
	"four": empty,
	"fourteen": empty,
	"fourth": empty,
	"fox": empty,
	"frame": empty,
	"free": empty,
	"freedom": empty,
	"freeze": empty,
	"freight": empty,
	"French": empty,
	"fresh": empty,
	"fret": empty,
	"Friday": empty,
	"fried": empty,
	"friend": empty,
	"friendly": empty,
	"friendship": empty,
	"frighten": empty,
	"frog": empty,
	"from": empty,
	"front": empty,
	"frost": empty,
	"frown": empty,
	"froze": empty,
	"fruit": empty,
	"fry": empty,
	"fudge": empty,
	"fuel": empty,
	"full": empty,
	"fully": empty,
	"fun": empty,
	"funny": empty,
	"fur": empty,
	"furniture": empty,
	"further": empty,
	"fuzzy": empty,
	"gain": empty,
	"gallon": empty,
	"gallop": empty,
	"game": empty,
	"gang": empty,
	"garage": empty,
	"garbage": empty,
	"garden": empty,
	"gas": empty,
	"gasoline": empty,
	"gate": empty,
	"gather": empty,
	"gave": empty,
	"gay": empty,
	"gear": empty,
	"geese": empty,
	"general": empty,
	"gentle": empty,
	"gentleman": empty,
	"gentlemen": empty,
	"geography": empty,
	"get": empty,
	"getting": empty,
	"giant": empty,
	"gift": empty,
	"gingerbread": empty,
	"girl": empty,
	"give": empty,
	"given": empty,
	"giving": empty,
	"glad": empty,
	"gladly": empty,
	"glance": empty,
	"glass": empty,
	"glasses": empty,
	"gleam": empty,
	"glide": empty,
	"glory": empty,
	"glove": empty,
	"glow": empty,
	"glue": empty,
	"go": empty,
	"going": empty,
	"goes": empty,
	"goal": empty,
	"goat": empty,
	"gobble": empty,
	"God": empty,
	"god": empty,
	"godmother": empty,
	"gold": empty,
	"golden": empty,
	"goldfish": empty,
	"golf": empty,
	"gone": empty,
	"good": empty,
	"goods": empty,
	"goodbye": empty,
	"good-by": empty,
	"good-bye": empty,
	"good-looking": empty,
	"goodness": empty,
	"goody": empty,
	"goose": empty,
	"gooseberry": empty,
	"got": empty,
	"govern": empty,
	"government": empty,
	"gown": empty,
	"grab": empty,
	"gracious": empty,
	"grade": empty,
	"grain": empty,
	"grand": empty,
	"grandchild": empty,
	"grandchildren": empty,
	"granddaughter": empty,
	"grandfather": empty,
	"grandma": empty,
	"grandmother": empty,
	"grandpa": empty,
	"grandson": empty,
	"grandstand": empty,
	"grape": empty,
	"grapes": empty,
	"grapefruit": empty,
	"grass": empty,
	"grasshopper": empty,
	"grateful": empty,
	"grave": empty,
	"gravel": empty,
	"graveyard": empty,
	"gravy": empty,
	"gray": empty,
	"graze": empty,
	"grease": empty,
	"great": empty,
	"green": empty,
	"greet": empty,
	"grew": empty,
	"grind": empty,
	"groan": empty,
	"grocery": empty,
	"ground": empty,
	"group": empty,
	"grove": empty,
	"grow": empty,
	"guard": empty,
	"guess": empty,
	"guest": empty,
	"guide": empty,
	"gulf": empty,
	"gum": empty,
	"gun": empty,
	"gunpowder": empty,
	"guy": empty,
	"ha": empty,
	"habit": empty,
	"had": empty,
	"hadn't": empty,
	"hail": empty,
	"hair": empty,
	"haircut": empty,
	"hairpin": empty,
	"half": empty,
	"hall": empty,
	"halt": empty,
	"ham": empty,
	"hammer": empty,
	"hand": empty,
	"handful": empty,
	"handkerchief": empty,
	"handle": empty,
	"handwriting": empty,
	"hang": empty,
	"happen": empty,
	"happily": empty,
	"happiness": empty,
	"happy": empty,
	"harbor": empty,
	"hard": empty,
	"hardly": empty,
	"hardship": empty,
	"hardware": empty,
	"hare": empty,
	"hark": empty,
	"harm": empty,
	"harness": empty,
	"harp": empty,
	"harvest": empty,
	"has": empty,
	"hasn't": empty,
	"haste": empty,
	"hasten": empty,
	"hasty": empty,
	"hat": empty,
	"hatch": empty,
	"hatchet": empty,
	"hate": empty,
	"haul": empty,
	"have": empty,
	"haven't": empty,
	"having": empty,
	"hawk": empty,
	"hay": empty,
	"hayfield": empty,
	"haystack": empty,
	"he": empty,
	"head": empty,
	"headache": empty,
	"heal": empty,
	"health": empty,
	"healthy": empty,
	"heap": empty,
	"hear": empty,
	"hearing": empty,
	"heard": empty,
	"heart": empty,
	"heat": empty,
	"heater": empty,
	"heaven": empty,
	"heavy": empty,
	"he'd": empty,
	"heel": empty,
	"height": empty,
	"held": empty,
	"hell": empty,
	"he'll": empty,
	"hello": empty,
	"helmet": empty,
	"help": empty,
	"helper": empty,
	"helpful": empty,
	"hem": empty,
	"hen": empty,
	"henhouse": empty,
	"her": empty,
	"hers": empty,
	"herd": empty,
	"here": empty,
	"here's": empty,
	"hero": empty,
	"herself": empty,
	"he's": empty,
	"hey": empty,
	"hickory": empty,
	"hid": empty,
	"hidden": empty,
	"hide": empty,
	"high": empty,
	"highway": empty,
	"hill": empty,
	"hillside": empty,
	"hilltop": empty,
	"hilly": empty,
	"him": empty,
	"himself": empty,
	"hind": empty,
	"hint": empty,
	"hip": empty,
	"hire": empty,
	"his": empty,
	"hiss": empty,
	"history": empty,
	"hit": empty,
	"hitch": empty,
	"hive": empty,
	"ho": empty,
	"hoe": empty,
	"hog": empty,
	"hold": empty,
	"holder": empty,
	"hole": empty,
	"holiday": empty,
	"hollow": empty,
	"holy": empty,
	"home": empty,
	"homely": empty,
	"homesick": empty,
	"honest": empty,
	"honey": empty,
	"honeybee": empty,
	"honeymoon": empty,
	"honk": empty,
	"honor": empty,
	"hood": empty,
	"hoof": empty,
	"hook": empty,
	"hoop": empty,
	"hop": empty,
	"hope": empty,
	"hopeful": empty,
	"hopeless": empty,
	"horn": empty,
	"horse": empty,
	"horseback": empty,
	"horseshoe": empty,
	"hose": empty,
	"hospital": empty,
	"host": empty,
	"hot": empty,
	"hotel": empty,
	"hound": empty,
	"hour": empty,
	"house": empty,
	"housetop": empty,
	"housewife": empty,
	"housework": empty,
	"how": empty,
	"however": empty,
	"howl": empty,
	"hug": empty,
	"huge": empty,
	"hum": empty,
	"humble": empty,
	"hump": empty,
	"hundred": empty,
	"hung": empty,
	"hunger": empty,
	"hungry": empty,
	"hunk": empty,
	"hunt": empty,
	"hunter": empty,
	"hurrah": empty,
	"hurried": empty,
	"hurry": empty,
	"hurt": empty,
	"husband": empty,
	"hush": empty,
	"hut": empty,
	"hymn": empty,
	"I": empty,
	"ice": empty,
	"icy": empty,
	"I'd": empty,
	"idea": empty,
	"ideal": empty,
	"if": empty,
	"ill": empty,
	"I'll": empty,
	"I'm": empty,
	"important": empty,
	"impossible": empty,
	"improve": empty,
	"in": empty,
	"inch": empty,
	"inches": empty,
	"income": empty,
	"indeed": empty,
	"Indian": empty,
	"indoors": empty,
	"ink": empty,
	"inn": empty,
	"insect": empty,
	"inside": empty,
	"instant": empty,
	"instead": empty,
	"insult": empty,
	"intend": empty,
	"interested": empty,
	"interesting": empty,
	"into": empty,
	"invite": empty,
	"iron": empty,
	"is": empty,
	"island": empty,
	"isn't": empty,
	"it": empty,
	"its": empty,
	"it's": empty,
	"itself": empty,
	"I've": empty,
	"ivory": empty,
	"ivy": empty,
	"jacket": empty,
	"jacks": empty,
	"jail": empty,
	"jam": empty,
	"January": empty,
	"jar": empty,
	"jaw": empty,
	"jay": empty,
	"jelly": empty,
	"jellyfish": empty,
	"jerk": empty,
	"jig": empty,
	"job": empty,
	"jockey": empty,
	"join": empty,
	"joke": empty,
	"joking": empty,
	"jolly": empty,
	"journey": empty,
	"joy": empty,
	"joyful": empty,
	"joyous": empty,
	"judge": empty,
	"jug": empty,
	"juice": empty,
	"juicy": empty,
	"July": empty,
	"jump": empty,
	"June": empty,
	"junior": empty,
	"junk": empty,
	"just": empty,
	"keen": empty,
	"keep": empty,
	"kept": empty,
	"kettle": empty,
	"key": empty,
	"kick": empty,
	"kid": empty,
	"kill": empty,
	"killed": empty,
	"kind": empty,
	"kindly": empty,
	"kindness": empty,
	"king": empty,
	"kingdom": empty,
	"kiss": empty,
	"kitchen": empty,
	"kite": empty,
	"kitten": empty,
	"kitty": empty,
	"knee": empty,
	"kneel": empty,
	"knew": empty,
	"knife": empty,
	"knit": empty,
	"knives": empty,
	"knob": empty,
	"knock": empty,
	"knot": empty,
	"know": empty,
	"known": empty,
	"lace": empty,
	"lad": empty,
	"ladder": empty,
	"ladies": empty,
	"lady": empty,
	"laid": empty,
	"lake": empty,
	"lamb": empty,
	"lame": empty,
	"lamp": empty,
	"land": empty,
	"lane": empty,
	"language": empty,
	"lantern": empty,
	"lap": empty,
	"lard": empty,
	"large": empty,
	"lash": empty,
	"lass": empty,
	"last": empty,
	"late": empty,
	"laugh": empty,
	"laundry": empty,
	"law": empty,
	"lawn": empty,
	"lawyer": empty,
	"lay": empty,
	"lazy": empty,
	"lead": empty,
	"leader": empty,
	"leaf": empty,
	"leak": empty,
	"lean": empty,
	"leap": empty,
	"learn": empty,
	"learned": empty,
	"least": empty,
	"leather": empty,
	"leave": empty,
	"leaving": empty,
	"led": empty,
	"left": empty,
	"leg": empty,
	"lemon": empty,
	"lemonade": empty,
	"lend": empty,
	"length": empty,
	"less": empty,
	"lesson": empty,
	"let": empty,
	"let's": empty,
	"letter": empty,
	"letting": empty,
	"lettuce": empty,
	"level": empty,
	"liberty": empty,
	"library": empty,
	"lice": empty,
	"lick": empty,
	"lid": empty,
	"lie": empty,
	"life": empty,
	"lift": empty,
	"light": empty,
	"lightness": empty,
	"lightning": empty,
	"like": empty,
	"likely": empty,
	"liking": empty,
	"lily": empty,
	"limb": empty,
	"lime": empty,
	"limp": empty,
	"line": empty,
	"linen": empty,
	"lion": empty,
	"lip": empty,
	"list": empty,
	"listen": empty,
	"lit": empty,
	"little": empty,
	"live": empty,
	"lives": empty,
	"lively": empty,
	"liver": empty,
	"living": empty,
	"lizard": empty,
	"load": empty,
	"loaf": empty,
	"loan": empty,
	"loaves": empty,
	"lock": empty,
	"locomotive": empty,
	"log": empty,
	"lone": empty,
	"lonely": empty,
	"lonesome": empty,
	"long": empty,
	"look": empty,
	"lookout": empty,
	"loop": empty,
	"loose": empty,
	"lord": empty,
	"lose": empty,
	"loser": empty,
	"loss": empty,
	"lost": empty,
	"lot": empty,
	"loud": empty,
	"love": empty,
	"lovely": empty,
	"lover": empty,
	"low": empty,
	"luck": empty,
	"lucky": empty,
	"lumber": empty,
	"lump": empty,
	"lunch": empty,
	"lying": empty,
	"ma": empty,
	"machine": empty,
	"machinery": empty,
	"mad": empty,
	"made": empty,
	"magazine": empty,
	"magic": empty,
	"maid": empty,
	"mail": empty,
	"mailbox": empty,
	"mailman": empty,
	"major": empty,
	"make": empty,
	"making": empty,
	"male": empty,
	"mama": empty,
	"mamma": empty,
	"man": empty,
	"manager": empty,
	"mane": empty,
	"manger": empty,
	"many": empty,
	"map": empty,
	"maple": empty,
	"marble": empty,
	"march": empty,
	"March": empty,
	"mare": empty,
	"mark": empty,
	"market": empty,
	"marriage": empty,
	"married": empty,
	"marry": empty,
	"mask": empty,
	"mast": empty,
	"master": empty,
	"mat": empty,
	"match": empty,
	"matter": empty,
	"mattress": empty,
	"may": empty,
	"May": empty,
	"maybe": empty,
	"mayor": empty,
	"maypole": empty,
	"me": empty,
	"meadow": empty,
	"meal": empty,
	"mean": empty,
	"means": empty,
	"meant": empty,
	"measure": empty,
	"meat": empty,
	"medicine": empty,
	"meet": empty,
	"meeting": empty,
	"melt": empty,
	"member": empty,
	"men": empty,
	"mend": empty,
	"meow": empty,
	"merry": empty,
	"mess": empty,
	"message": empty,
	"met": empty,
	"metal": empty,
	"mew": empty,
	"mice": empty,
	"middle": empty,
	"midnight": empty,
	"might": empty,
	"mighty": empty,
	"mile": empty,
	"milk": empty,
	"milkman": empty,
	"mill": empty,
	"miler": empty,
	"million": empty,
	"mind": empty,
	"mine": empty,
	"miner": empty,
	"mint": empty,
	"minute": empty,
	"mirror": empty,
	"mischief": empty,
	"miss": empty,
	"Miss": empty,
	"misspell": empty,
	"mistake": empty,
	"misty": empty,
	"mitt": empty,
	"mitten": empty,
	"mix": empty,
	"moment": empty,
	"Monday": empty,
	"money": empty,
	"monkey": empty,
	"month": empty,
	"moo": empty,
	"moon": empty,
	"moonlight": empty,
	"moose": empty,
	"mop": empty,
	"more": empty,
	"morning": empty,
	"morrow": empty,
	"moss": empty,
	"most": empty,
	"mostly": empty,
	"mother": empty,
	"motor": empty,
	"mount": empty,
	"mountain": empty,
	"mouse": empty,
	"mouth": empty,
	"move": empty,
	"movie": empty,
	"movies": empty,
	"moving": empty,
	"mow": empty,
	"Mr.": empty,
	"Mrs.": empty,
	"much": empty,
	"mud": empty,
	"muddy": empty,
	"mug": empty,
	"mule": empty,
	"multiply": empty,
	"murder": empty,
	"music": empty,
	"must": empty,
	"my": empty,
	"myself": empty,
	"nail": empty,
	"name": empty,
	"nap": empty,
	"napkin": empty,
	"narrow": empty,
	"nasty": empty,
	"naughty": empty,
	"navy": empty,
	"near": empty,
	"nearby": empty,
	"nearly": empty,
	"neat": empty,
	"neck": empty,
	"necktie": empty,
	"need": empty,
	"needle": empty,
	"needn't": empty,
	"Negro": empty,
	"neighbor": empty,
	"neighborhood": empty,
	"neither": empty,
	"nerve": empty,
	"nest": empty,
	"net": empty,
	"never": empty,
	"nevermore": empty,
	"new": empty,
	"news": empty,
	"newspaper": empty,
	"next": empty,
	"nibble": empty,
	"nice": empty,
	"nickel": empty,
	"night": empty,
	"nightgown": empty,
	"nine": empty,
	"nineteen": empty,
	"ninety": empty,
	"no": empty,
	"nobody": empty,
	"nod": empty,
	"noise": empty,
	"noisy": empty,
	"none": empty,
	"noon": empty,
	"nor": empty,
	"north": empty,
	"northern": empty,
	"nose": empty,
	"not": empty,
	"note": empty,
	"nothing": empty,
	"notice": empty,
	"November": empty,
	"now": empty,
	"nowhere": empty,
	"number": empty,
	"nurse": empty,
	"nut": empty,
	"oak": empty,
	"oar": empty,
	"oatmeal": empty,
	"oats": empty,
	"obey": empty,
	"ocean": empty,
	"o'clock": empty,
	"October": empty,
	"odd": empty,
	"of": empty,
	"off": empty,
	"offer": empty,
	"office": empty,
	"officer": empty,
	"often": empty,
	"oh": empty,
	"oil": empty,
	"old": empty,
	"old-fashioned": empty,
	"on": empty,
	"once": empty,
	"one": empty,
	"onion": empty,
	"only": empty,
	"onward": empty,
	"open": empty,
	"or": empty,
	"orange": empty,
	"orchard": empty,
	"order": empty,
	"ore": empty,
	"organ": empty,
	"other": empty,
	"otherwise": empty,
	"ouch": empty,
	"ought": empty,
	"our": empty,
	"ours": empty,
	"ourselves": empty,
	"out": empty,
	"outdoors": empty,
	"outfit": empty,
	"outlaw": empty,
	"outline": empty,
	"outside": empty,
	"outward": empty,
	"oven": empty,
	"over": empty,
	"overalls": empty,
	"overcoat": empty,
	"overeat": empty,
	"overhead": empty,
	"overhear": empty,
	"overnight": empty,
	"overturn": empty,
	"owe": empty,
	"owing": empty,
	"owl": empty,
	"own": empty,
	"owner": empty,
	"ox": empty,
	"pa": empty,
	"pace": empty,
	"pack": empty,
	"package": empty,
	"pad": empty,
	"page": empty,
	"paid": empty,
	"pail": empty,
	"pain": empty,
	"painful": empty,
	"paint": empty,
	"painter": empty,
	"painting": empty,
	"pair": empty,
	"pal": empty,
	"palace": empty,
	"pale": empty,
	"pan": empty,
	"pancake": empty,
	"pane": empty,
	"pansy": empty,
	"pants": empty,
	"papa": empty,
	"paper": empty,
	"parade": empty,
	"pardon": empty,
	"parent": empty,
	"park": empty,
	"part": empty,
	"partly": empty,
	"partner": empty,
	"party": empty,
	"pass": empty,
	"passenger": empty,
	"past": empty,
	"paste": empty,
	"pasture": empty,
	"pat": empty,
	"patch": empty,
	"path": empty,
	"patter": empty,
	"pave": empty,
	"pavement": empty,
	"paw": empty,
	"pay": empty,
	"payment": empty,
	"pea": empty,
	"peas": empty,
	"peace": empty,
	"peaceful": empty,
	"peach": empty,
	"peaches": empty,
	"peak": empty,
	"peanut": empty,
	"pear": empty,
	"pearl": empty,
	"peck": empty,
	"peek": empty,
	"peel": empty,
	"peep": empty,
	"peg": empty,
	"pen": empty,
	"pencil": empty,
	"penny": empty,
	"people": empty,
	"pepper": empty,
	"peppermint": empty,
	"perfume": empty,
	"perhaps": empty,
	"person": empty,
	"pet": empty,
	"phone": empty,
	"piano": empty,
	"pick": empty,
	"pickle": empty,
	"picnic": empty,
	"picture": empty,
	"pie": empty,
	"piece": empty,
	"pig": empty,
	"pigeon": empty,
	"piggy": empty,
	"pile": empty,
	"pill": empty,
	"pillow": empty,
	"pin": empty,
	"pine": empty,
	"pineapple": empty,
	"pink": empty,
	"pint": empty,
	"pipe": empty,
	"pistol": empty,
	"pit": empty,
	"pitch": empty,
	"pitcher": empty,
	"pity": empty,
	"place": empty,
	"plain": empty,
	"plan": empty,
	"plane": empty,
	"plant": empty,
	"plate": empty,
	"platform": empty,
	"platter": empty,
	"play": empty,
	"player": empty,
	"playground": empty,
	"playhouse": empty,
	"playmate": empty,
	"plaything": empty,
	"pleasant": empty,
	"please": empty,
	"pleasure": empty,
	"plenty": empty,
	"plow": empty,
	"plug": empty,
	"plum": empty,
	"pocket": empty,
	"pocketbook": empty,
	"poem": empty,
	"point": empty,
	"poison": empty,
	"poke": empty,
	"pole": empty,
	"police": empty,
	"policeman": empty,
	"polish": empty,
	"polite": empty,
	"pond": empty,
	"ponies": empty,
	"pony": empty,
	"pool": empty,
	"poor": empty,
	"pop": empty,
	"popcorn": empty,
	"popped": empty,
	"porch": empty,
	"pork": empty,
	"possible": empty,
	"post": empty,
	"postage": empty,
	"postman": empty,
	"pot": empty,
	"potato": empty,
	"potatoes": empty,
	"pound": empty,
	"pour": empty,
	"powder": empty,
	"power": empty,
	"powerful": empty,
	"praise": empty,
	"pray": empty,
	"prayer": empty,
	"prepare": empty,
	"present": empty,
	"pretty": empty,
	"price": empty,
	"prick": empty,
	"prince": empty,
	"princess": empty,
	"print": empty,
	"prison": empty,
	"prize": empty,
	"promise": empty,
	"proper": empty,
	"protect": empty,
	"proud": empty,
	"prove": empty,
	"prune": empty,
	"public": empty,
	"puddle": empty,
	"puff": empty,
	"pull": empty,
	"pump": empty,
	"pumpkin": empty,
	"punch": empty,
	"punish": empty,
	"pup": empty,
	"pupil": empty,
	"puppy": empty,
	"pure": empty,
	"purple": empty,
	"purse": empty,
	"push": empty,
	"puss": empty,
	"pussy": empty,
	"pussycat": empty,
	"put": empty,
	"putting": empty,
	"puzzle": empty,
	"quack": empty,
	"quart": empty,
	"quarter": empty,
	"queen": empty,
	"queer": empty,
	"question": empty,
	"quick": empty,
	"quickly": empty,
	"quiet": empty,
	"quilt": empty,
	"quit": empty,
	"quite": empty,
	"rabbit": empty,
	"race": empty,
	"rack": empty,
	"radio": empty,
	"radish": empty,
	"rag": empty,
	"rail": empty,
	"railroad": empty,
	"railway": empty,
	"rain": empty,
	"rainy": empty,
	"rainbow": empty,
	"raise": empty,
	"raisin": empty,
	"rake": empty,
	"ram": empty,
	"ran": empty,
	"ranch": empty,
	"rang": empty,
	"rap": empty,
	"rapidly": empty,
	"rat": empty,
	"rate": empty,
	"rather": empty,
	"rattle": empty,
	"raw": empty,
	"ray": empty,
	"reach": empty,
	"read": empty,
	"reader": empty,
	"reading": empty,
	"ready": empty,
	"real": empty,
	"really": empty,
	"reap": empty,
	"rear": empty,
	"reason": empty,
	"rebuild": empty,
	"receive": empty,
	"recess": empty,
	"record": empty,
	"red": empty,
	"redbird": empty,
	"redbreast": empty,
	"refuse": empty,
	"reindeer": empty,
	"rejoice": empty,
	"remain": empty,
	"remember": empty,
	"remind": empty,
	"remove": empty,
	"rent": empty,
	"repair": empty,
	"repay": empty,
	"repeat": empty,
	"report": empty,
	"rest": empty,
	"return": empty,
	"review": empty,
	"reward": empty,
	"rib": empty,
	"ribbon": empty,
	"rice": empty,
	"rich": empty,
	"rid": empty,
	"riddle": empty,
	"ride": empty,
	"rider": empty,
	"riding": empty,
	"right": empty,
	"rim": empty,
	"ring": empty,
	"rip": empty,
	"ripe": empty,
	"rise": empty,
	"rising": empty,
	"river": empty,
	"road": empty,
	"roadside": empty,
	"roar": empty,
	"roast": empty,
	"rob": empty,
	"robber": empty,
	"robe": empty,
	"robin": empty,
	"rock": empty,
	"rocky": empty,
	"rocket": empty,
	"rode": empty,
	"roll": empty,
	"roller": empty,
	"roof": empty,
	"room": empty,
	"rooster": empty,
	"root": empty,
	"rope": empty,
	"rose": empty,
	"rosebud": empty,
	"rot": empty,
	"rotten": empty,
	"rough": empty,
	"round": empty,
	"route": empty,
	"row": empty,
	"rowboat": empty,
	"royal": empty,
	"rub": empty,
	"rubbed": empty,
	"rubber": empty,
	"rubbish": empty,
	"rug": empty,
	"rule": empty,
	"ruler": empty,
	"rumble": empty,
	"run": empty,
	"rung": empty,
	"runner": empty,
	"running": empty,
	"rush": empty,
	"rust": empty,
	"rusty": empty,
	"rye": empty,
	"sack": empty,
	"sad": empty,
	"saddle": empty,
	"sadness": empty,
	"safe": empty,
	"safety": empty,
	"said": empty,
	"sail": empty,
	"sailboat": empty,
	"sailor": empty,
	"saint": empty,
	"salad": empty,
	"sale": empty,
	"salt": empty,
	"same": empty,
	"sand": empty,
	"sandy": empty,
	"sandwich": empty,
	"sang": empty,
	"sank": empty,
	"sap": empty,
	"sash": empty,
	"sat": empty,
	"satin": empty,
	"satisfactory": empty,
	"Saturday": empty,
	"sausage": empty,
	"savage": empty,
	"save": empty,
	"savings": empty,
	"saw": empty,
	"say": empty,
	"scab": empty,
	"scales": empty,
	"scare": empty,
	"scarf": empty,
	"school": empty,
	"schoolboy": empty,
	"schoolhouse": empty,
	"schoolmaster": empty,
	"schoolroom": empty,
	"scorch": empty,
	"score": empty,
	"scrap": empty,
	"scrape": empty,
	"scratch": empty,
	"scream": empty,
	"screen": empty,
	"screw": empty,
	"scrub": empty,
	"sea": empty,
	"seal": empty,
	"seam": empty,
	"search": empty,
	"season": empty,
	"seat": empty,
	"second": empty,
	"secret": empty,
	"see": empty,
	"seeing": empty,
	"seed": empty,
	"seek": empty,
	"seem": empty,
	"seen": empty,
	"seesaw": empty,
	"select": empty,
	"self": empty,
	"selfish": empty,
	"sell": empty,
	"send": empty,
	"sense": empty,
	"sent": empty,
	"sentence": empty,
	"separate": empty,
	"September": empty,
	"servant": empty,
	"serve": empty,
	"service": empty,
	"set": empty,
	"setting": empty,
	"settle": empty,
	"settlement": empty,
	"seven": empty,
	"seventeen": empty,
	"seventh": empty,
	"seventy": empty,
	"several": empty,
	"sew": empty,
	"shade": empty,
	"shadow": empty,
	"shady": empty,
	"shake": empty,
	"shaker": empty,
	"shaking": empty,
	"shall": empty,
	"shame": empty,
	"shan't": empty,
	"shape": empty,
	"share": empty,
	"sharp": empty,
	"shave": empty,
	"she": empty,
	"she'd": empty,
	"she'll": empty,
	"she's": empty,
	"shear": empty,
	"shears": empty,
	"shed": empty,
	"sheep": empty,
	"sheet": empty,
	"shelf": empty,
	"shell": empty,
	"shepherd": empty,
	"shine": empty,
	"shining": empty,
	"shiny": empty,
	"ship": empty,
	"shirt": empty,
	"shock": empty,
	"shoe": empty,
	"shoemaker": empty,
	"shone": empty,
	"shook": empty,
	"shoot": empty,
	"shop": empty,
	"shopping": empty,
	"shore": empty,
	"short": empty,
	"shot": empty,
	"should": empty,
	"shoulder": empty,
	"shouldn't": empty,
	"shout": empty,
	"shovel": empty,
	"show": empty,
	"shower": empty,
	"shut": empty,
	"shy": empty,
	"sick": empty,
	"sickness": empty,
	"side": empty,
	"sidewalk": empty,
	"sideways": empty,
	"sigh": empty,
	"sight": empty,
	"sign": empty,
	"silence": empty,
	"silent": empty,
	"silk": empty,
	"sill": empty,
	"silly": empty,
	"silver": empty,
	"simple": empty,
	"sin": empty,
	"since": empty,
	"sing": empty,
	"singer": empty,
	"single": empty,
	"sink": empty,
	"sip": empty,
	"sir": empty,
	"sis": empty,
	"sissy": empty,
	"sister": empty,
	"sit": empty,
	"sitting": empty,
	"six": empty,
	"sixteen": empty,
	"sixth": empty,
	"sixty": empty,
	"size": empty,
	"skate": empty,
	"skater": empty,
	"ski": empty,
	"skin": empty,
	"skip": empty,
	"skirt": empty,
	"sky": empty,
	"slam": empty,
	"slap": empty,
	"slate": empty,
	"slave": empty,
	"sled": empty,
	"sleep": empty,
	"sleepy": empty,
	"sleeve": empty,
	"sleigh": empty,
	"slept": empty,
	"slice": empty,
	"slid": empty,
	"slide": empty,
	"sling": empty,
	"slip": empty,
	"slipped": empty,
	"slipper": empty,
	"slippery": empty,
	"slit": empty,
	"slow": empty,
	"slowly": empty,
	"sly": empty,
	"smack": empty,
	"small": empty,
	"smart": empty,
	"smell": empty,
	"smile": empty,
	"smoke": empty,
	"smooth": empty,
	"snail": empty,
	"snake": empty,
	"snap": empty,
	"snapping": empty,
	"sneeze": empty,
	"snow": empty,
	"snowy": empty,
	"snowball": empty,
	"snowflake": empty,
	"snuff": empty,
	"snug": empty,
	"so": empty,
	"soak": empty,
	"soap": empty,
	"sob": empty,
	"socks": empty,
	"sod": empty,
	"soda": empty,
	"sofa": empty,
	"soft": empty,
	"soil": empty,
	"sold": empty,
	"soldier": empty,
	"sole": empty,
	"some": empty,
	"somebody": empty,
	"somehow": empty,
	"someone": empty,
	"something": empty,
	"sometime": empty,
	"sometimes": empty,
	"somewhere": empty,
	"son": empty,
	"song": empty,
	"soon": empty,
	"sore": empty,
	"sorrow": empty,
	"sorry": empty,
	"sort": empty,
	"soul": empty,
	"sound": empty,
	"soup": empty,
	"sour": empty,
	"south": empty,
	"southern": empty,
	"space": empty,
	"spade": empty,
	"spank": empty,
	"sparrow": empty,
	"speak": empty,
	"speaker": empty,
	"spear": empty,
	"speech": empty,
	"speed": empty,
	"spell": empty,
	"spelling": empty,
	"spend": empty,
	"spent": empty,
	"spider": empty,
	"spike": empty,
	"spill": empty,
	"spin": empty,
	"spinach": empty,
	"spirit": empty,
	"spit": empty,
	"splash": empty,
	"spoil": empty,
	"spoke": empty,
	"spook": empty,
	"spoon": empty,
	"sport": empty,
	"spot": empty,
	"spread": empty,
	"spring": empty,
	"springtime": empty,
	"sprinkle": empty,
	"square": empty,
	"squash": empty,
	"squeak": empty,
	"squeeze": empty,
	"squirrel": empty,
	"stable": empty,
	"stack": empty,
	"stage": empty,
	"stair": empty,
	"stall": empty,
	"stamp": empty,
	"stand": empty,
	"star": empty,
	"stare": empty,
	"start": empty,
	"starve": empty,
	"state": empty,
	"station": empty,
	"stay": empty,
	"steak": empty,
	"steal": empty,
	"steam": empty,
	"steamboat": empty,
	"steamer": empty,
	"steel": empty,
	"steep": empty,
	"steeple": empty,
	"steer": empty,
	"stem": empty,
	"step": empty,
	"stepping": empty,
	"stick": empty,
	"sticky": empty,
	"stiff": empty,
	"still": empty,
	"stillness": empty,
	"sting": empty,
	"stir": empty,
	"stitch": empty,
	"stock": empty,
	"stocking": empty,
	"stole": empty,
	"stone": empty,
	"stood": empty,
	"stool": empty,
	"stoop": empty,
	"stop": empty,
	"stopped": empty,
	"stopping": empty,
	"store": empty,
	"stork": empty,
	"stories": empty,
	"storm": empty,
	"stormy": empty,
	"story": empty,
	"stove": empty,
	"straight": empty,
	"strange": empty,
	"stranger": empty,
	"strap": empty,
	"straw": empty,
	"strawberry": empty,
	"stream": empty,
	"street": empty,
	"stretch": empty,
	"string": empty,
	"strip": empty,
	"stripes": empty,
	"strong": empty,
	"stuck": empty,
	"study": empty,
	"stuff": empty,
	"stump": empty,
	"stung": empty,
	"subject": empty,
	"such": empty,
	"suck": empty,
	"sudden": empty,
	"suffer": empty,
	"sugar": empty,
	"suit": empty,
	"sum": empty,
	"summer": empty,
	"sun": empty,
	"Sunday": empty,
	"sunflower": empty,
	"sung": empty,
	"sunk": empty,
	"sunlight": empty,
	"sunny": empty,
	"sunrise": empty,
	"sunset": empty,
	"sunshine": empty,
	"supper": empty,
	"suppose": empty,
	"sure": empty,
	"surely": empty,
	"surface": empty,
	"surprise": empty,
	"swallow": empty,
	"swam": empty,
	"swamp": empty,
	"swan": empty,
	"swat": empty,
	"swear": empty,
	"sweat": empty,
	"sweater": empty,
	"sweep": empty,
	"sweet": empty,
	"sweetness": empty,
	"sweetheart": empty,
	"swell": empty,
	"swept": empty,
	"swift": empty,
	"swim": empty,
	"swimming": empty,
	"swing": empty,
	"switch": empty,
	"sword": empty,
	"swore": empty,
	"table": empty,
	"tablecloth": empty,
	"tablespoon": empty,
	"tablet": empty,
	"tack": empty,
	"tag": empty,
	"tail": empty,
	"tailor": empty,
	"take": empty,
	"taken": empty,
	"taking": empty,
	"tale": empty,
	"talk": empty,
	"talker": empty,
	"tall": empty,
	"tame": empty,
	"tan": empty,
	"tank": empty,
	"tap": empty,
	"tape": empty,
	"tar": empty,
	"tardy": empty,
	"task": empty,
	"taste": empty,
	"taught": empty,
	"tax": empty,
	"tea": empty,
	"teach": empty,
	"teacher": empty,
	"team": empty,
	"tear": empty,
	"tease": empty,
	"teaspoon": empty,
	"teeth": empty,
	"telephone": empty,
	"tell": empty,
	"temper": empty,
	"ten": empty,
	"tennis": empty,
	"tent": empty,
	"term": empty,
	"terrible": empty,
	"test": empty,
	"than": empty,
	"thank": empty,
	"thanks": empty,
	"thankful": empty,
	"Thanksgiving": empty,
	"that": empty,
	"that's": empty,
	"the": empty,
	"theater": empty,
	"thee": empty,
	"their": empty,
	"them": empty,
	"then": empty,
	"there": empty,
	"these": empty,
	"they": empty,
	"they'd": empty,
	"they'll": empty,
	"they're": empty,
	"they've": empty,
	"thick": empty,
	"thief": empty,
	"thimble": empty,
	"thin": empty,
	"thing": empty,
	"think": empty,
	"third": empty,
	"thirsty": empty,
	"thirteen": empty,
	"thirty": empty,
	"this": empty,
	"thorn": empty,
	"those": empty,
	"though": empty,
	"thought": empty,
	"thousand": empty,
	"thread": empty,
	"three": empty,
	"threw": empty,
	"throat": empty,
	"throne": empty,
	"through": empty,
	"throw": empty,
	"thrown": empty,
	"thumb": empty,
	"thunder": empty,
	"Thursday": empty,
	"thy": empty,
	"tick": empty,
	"ticket": empty,
	"tickle": empty,
	"tie": empty,
	"tiger": empty,
	"tight": empty,
	"till": empty,
	"time": empty,
	"tin": empty,
	"tinkle": empty,
	"tiny": empty,
	"tip": empty,
	"tiptoe": empty,
	"tire": empty,
	"tired": empty,
	"title": empty,
	"to": empty,
	"toad": empty,
	"toadstool": empty,
	"toast": empty,
	"tobacco": empty,
	"today": empty,
	"toe": empty,
	"together": empty,
	"toilet": empty,
	"told": empty,
	"tomato": empty,
	"tomorrow": empty,
	"ton": empty,
	"tone": empty,
	"tongue": empty,
	"tonight": empty,
	"too": empty,
	"took": empty,
	"tool": empty,
	"toot": empty,
	"tooth": empty,
	"toothbrush": empty,
	"toothpick": empty,
	"top": empty,
	"tore": empty,
	"torn": empty,
	"toss": empty,
	"touch": empty,
	"tow": empty,
	"toward": empty,
	"towards": empty,
	"towel": empty,
	"tower": empty,
	"town": empty,
	"toy": empty,
	"trace": empty,
	"track": empty,
	"trade": empty,
	"train": empty,
	"tramp": empty,
	"trap": empty,
	"tray": empty,
	"treasure": empty,
	"treat": empty,
	"tree": empty,
	"trick": empty,
	"tricycle": empty,
	"tried": empty,
	"trim": empty,
	"trip": empty,
	"trolley": empty,
	"trouble": empty,
	"truck": empty,
	"true": empty,
	"truly": empty,
	"trunk": empty,
	"trust": empty,
	"truth": empty,
	"try": empty,
	"tub": empty,
	"Tuesday": empty,
	"tug": empty,
	"tulip": empty,
	"tumble": empty,
	"tune": empty,
	"tunnel": empty,
	"turkey": empty,
	"turn": empty,
	"turtle": empty,
	"twelve": empty,
	"twenty": empty,
	"twice": empty,
	"twig": empty,
	"twin": empty,
	"two": empty,
	"ugly": empty,
	"umbrella": empty,
	"uncle": empty,
	"under": empty,
	"understand": empty,
	"underwear": empty,
	"undress": empty,
	"unfair": empty,
	"unfinished": empty,
	"unfold": empty,
	"unfriendly": empty,
	"unhappy": empty,
	"unhurt": empty,
	"uniform": empty,
	"United": empty,
	"States": empty,
	"unkind": empty,
	"unknown": empty,
	"unless": empty,
	"unpleasant": empty,
	"until": empty,
	"unwilling": empty,
	"up": empty,
	"upon": empty,
	"upper": empty,
	"upset": empty,
	"upside": empty,
	"upstairs": empty,
	"uptown": empty,
	"upward": empty,
	"us": empty,
	"use": empty,
	"used": empty,
	"useful": empty,
	"valentine": empty,
	"valley": empty,
	"valuable": empty,
	"value": empty,
	"vase": empty,
	"vegetable": empty,
	"velvet": empty,
	"very": empty,
	"vessel": empty,
	"victory": empty,
	"view": empty,
	"village": empty,
	"vine": empty,
	"violet": empty,
	"visit": empty,
	"visitor": empty,
	"voice": empty,
	"vote": empty,
	"wag": empty,
	"wagon": empty,
	"waist": empty,
	"wait": empty,
	"wake": empty,
	"waken": empty,
	"walk": empty,
	"wall": empty,
	"walnut": empty,
	"want": empty,
	"war": empty,
	"warm": empty,
	"warn": empty,
	"was": empty,
	"wash": empty,
	"washer": empty,
	"washtub": empty,
	"wasn't": empty,
	"waste": empty,
	"watch": empty,
	"watchman": empty,
	"water": empty,
	"watermelon": empty,
	"waterproof": empty,
	"wave": empty,
	"wax": empty,
	"way": empty,
	"wayside": empty,
	"we": empty,
	"weak": empty,
	"weakness": empty,
	"weaken": empty,
	"wealth": empty,
	"weapon": empty,
	"wear": empty,
	"weary": empty,
	"weather": empty,
	"weave": empty,
	"web": empty,
	"we'd": empty,
	"wedding": empty,
	"Wednesday": empty,
	"wee": empty,
	"weed": empty,
	"week": empty,
	"we'll": empty,
	"weep": empty,
	"weigh": empty,
	"welcome": empty,
	"well": empty,
	"went": empty,
	"were": empty,
	"we're": empty,
	"west": empty,
	"western": empty,
	"wet": empty,
	"we've": empty,
	"whale": empty,
	"what": empty,
	"what's": empty,
	"wheat": empty,
	"wheel": empty,
	"when": empty,
	"whenever": empty,
	"where": empty,
	"which": empty,
	"while": empty,
	"whip": empty,
	"whipped": empty,
	"whirl": empty,
	"whisky": empty,
	"whiskey": empty,
	"whisper": empty,
	"whistle": empty,
	"white": empty,
	"who": empty,
	"who'd": empty,
	"whole": empty,
	"who'll": empty,
	"whom": empty,
	"who's": empty,
	"whose": empty,
	"why": empty,
	"wicked": empty,
	"wide": empty,
	"wife": empty,
	"wiggle": empty,
	"wild": empty,
	"wildcat": empty,
	"will": empty,
	"willing": empty,
	"willow": empty,
	"win": empty,
	"wind": empty,
	"windy": empty,
	"windmill": empty,
	"window": empty,
	"wine": empty,
	"wing": empty,
	"wink": empty,
	"winner": empty,
	"winter": empty,
	"wipe": empty,
	"wire": empty,
	"wise": empty,
	"wish": empty,
	"wit": empty,
	"witch": empty,
	"with": empty,
	"without": empty,
	"woke": empty,
	"wolf": empty,
	"woman": empty,
	"women": empty,
	"won": empty,
	"wonder": empty,
	"wonderful": empty,
	"won't": empty,
	"wood": empty,
	"wooden": empty,
	"woodpecker": empty,
	"woods": empty,
	"wool": empty,
	"woolen": empty,
	"word": empty,
	"wore": empty,
	"work": empty,
	"worker": empty,
	"workman": empty,
	"world": empty,
	"worm": empty,
	"worn": empty,
	"worry": empty,
	"worse": empty,
	"worst": empty,
	"worth": empty,
	"would": empty,
	"wouldn't": empty,
	"wound": empty,
	"wove": empty,
	"wrap": empty,
	"wrapped": empty,
	"wreck": empty,
	"wren": empty,
	"wring": empty,
	"write": empty,
	"writing": empty,
	"written": empty,
	"wrong": empty,
	"wrote": empty,
	"wrung": empty,
	"yard": empty,
	"yarn": empty,
	"year": empty,
	"yell": empty,
	"yellow": empty,
	"yes": empty,
	"yesterday": empty,
	"yet": empty,
	"yolk": empty,
	"yonder": empty,
	"you": empty,
	"you'd": empty,
	"you'll": empty,
	"young": empty,
	"youngster": empty,
	"your": empty,
	"yours": empty,
	"you're": empty,
	"yourself": empty,
	"yourselves": empty,
}
